@@ -1,4 +1,4 @@
-// Copyright (C) 2021 Joel Rosdahl and other contributors
+// Copyright (C) 2021-2022 Joel Rosdahl and other contributors
 //
 // See doc/AUTHORS.adoc for a complete list of contributors.
 //
@@ -27,12 +27,18 @@ namespace util {
 
 // --- Interface ---
 
+const char* get_dev_null_path();
+
 // Return whether `path` is absolute.
 bool is_absolute_path(nonstd::string_view path);
 
 // Return whether `path` includes at least one directory separator.
 bool is_full_path(nonstd::string_view path);
 
+// Return whether `path` starts with `prefix` considering path specifics on
+// Windows
+bool path_starts_with(nonstd::string_view path, nonstd::string_view prefix);
+
 // Split a list of paths (such as the content of $PATH on Unix platforms or
 // %PATH% on Windows platforms) into paths.
 std::vector<std::string> split_path_list(nonstd::string_view path_list);
