@@ -1,4 +1,4 @@
-// Copyright (C) 2010-2021 Joel Rosdahl and other contributors
+// Copyright (C) 2010-2022 Joel Rosdahl and other contributors
 //
 // See doc/AUTHORS.adoc for a complete list of contributors.
 //
@@ -569,6 +569,8 @@ TEST_CASE("-Xclang")
 {
   TestContext test_context;
   Context ctx;
+  ctx.config.set_compiler_type(CompilerType::clang);
+
   const std::string common_args =
     "-Xclang -fno-pch-timestamp"
     " -Xclang unsupported";
@@ -586,17 +588,17 @@ TEST_CASE("-Xclang")
     " -Xclang -include-pth -Xclang pth_path2";
 
   ctx.orig_args =
-    Args::from_string("gcc -c foo.c " + common_args + " " + color_diag + " "
+    Args::from_string("clang -c foo.c " + common_args + " " + color_diag + " "
                       + extra_args + " " + pch_pth_variants);
   Util::write_file("foo.c", "");
 
   const ProcessArgsResult result = process_args(ctx);
   CHECK(result.preprocessor_args.to_string()
-        == "gcc " + common_args + " " + pch_pth_variants);
+        == "clang " + common_args + " " + pch_pth_variants);
   CHECK(result.extra_args_to_hash.to_string() == extra_args);
   CHECK(result.compiler_args.to_string()
-        == "gcc " + common_args + " " + color_diag + " " + extra_args + " "
-             + pch_pth_variants + " -c");
+        == "clang " + common_args + " " + color_diag + " " + extra_args + " "
+             + pch_pth_variants + " -c -fcolor-diagnostics");
 }
 
 TEST_CASE("-x")
